<?php

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use SGalinski\SgJobs\Event\Listener\AccessPageListEventListener;
use SGalinski\SgJobs\Event\Listener\ExcludeFromReferenceIndexListener;
use SGalinski\SgJobs\Preview\PreviewRenderer;
use SGalinski\SgJobs\Service\BackendService;
use SGalinski\SgJobs\Service\SitemapService;
use Symfony\Component\DependencyInjection\Loader\Configurator\ContainerConfigurator;
use TYPO3\CMS\Core\DataHandling\Event\IsTableExcludedFromReferenceIndexEvent;

return static function (ContainerConfigurator $containerConfigurator): void {
	$services = $containerConfigurator->services();
	$services->defaults()
		->private()
		->autowire()
		->autoconfigure();
	$services->load('SGalinski\\SgJobs\\', __DIR__ . '/../Classes/');

	$services->set(SitemapService::class)->public();
	$services->set(BackendService::class)->public();
	$services->set(PreviewRenderer::class)->public();

	if (class_exists('\SGalinski\SgSeo\Events\AccessPageListEvent')) {
		$services->set(AccessPageListEventListener::class)
			->tag('event.listener', [
				'identifier' => 'accessPageListEvent',
				'event' => 'SGalinski\SgSeo\Events\AccessPageListEvent'
			]);
	}

	$services->set(ExcludeFromReferenceIndexListener::class)
		->tag('event.listener', [
			'identifier' => 'sg-jobs/excludeFromRefIndex',
			'event' => IsTableExcludedFromReferenceIndexEvent::class
		]);
};
